@@ -1,5 +1,5 @@
 ####################################################################################
-####                     Deep Time Series Pre-Alpha  0.1.1                      ####
+####                     Deep Time Series Early Alpha  0.1.1                    ####
 ####                           Python 3 Version                                 ####
 ####                    Conceived and Developed by Kevin Chen                   ####
 ####                        All Rights Reserved                                 ####
@@ -28,7 +28,8 @@ from statsmodels.tsa.stattools import adfuller
 from .__version__ import __version__
 # Models
 from .models import build_arima_model, build_sarimax_model, build_var_model, \
-                    build_pyflux_model, build_prophet_model, run_ensemble_model
+                    build_pyflux_model, build_prophet_model, run_ensemble_model, \
+                    run_deep_model
 # Utils
 from .utils import colorful, load_ts_data, clean_ts_data, convert_timeseries_dataframe_to_supervised, \
                    time_series_plot, print_static_rmse, print_dynamic_rmse
@@ -638,6 +639,17 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True, timezon
     print("STEP 10) Model Search IV (DL Models)")
     print("-------------------------------------------------------------------\n")
 
+    if model_type.lower() in ['dl', 'deep', 'prophet', 'all']:
+
+        if tf.test.is_gpu_available():
+            print("GPU is enabled.")
+        else:
+            print("Running on CPU as GPU is not enabled.")
+
+        dl_dict = run_deep_model(X_train, y_train, X_val, y_val, n_input, n_output,
+                                 n_units, d_rate, n_epoch, n_batch, score_type)
+        ipdb.set_trace()
+        pass
 
     print("\n\n-------------------------------------------------------------------")
     print("STEP 11) Model Results Output")
